@@ -24,7 +24,7 @@ fn test_yaml() {
     assert_eq!(
         ans[0],
         node!({
-            node!("a0 bb") => node!("val"),
+            node!("a0 bb") => node!(".val."),
             node!("::a1") => node!({
                 node!("b1") => node!(4.),
                 node!("b2") => node!([
@@ -33,6 +33,7 @@ fn test_yaml() {
                     node!(Yaml::Float("NaN".to_owned())),
                     node!(Yaml::Float("-inf".to_owned())),
                     node!("-.infs"),
+                    node!("2001-11-23 15:01:42 -5"),
                 ]),
             }),
             node!("-a2") => node!(4.03),
@@ -50,14 +51,16 @@ fn test_yaml() {
             node!(*("y")) => node!("b3, b4"),
             node!("test multiline") => node!([
                 node!({
-                    node!("folded") => node!("aaa bbb ccc\nddd\n"),
-                    node!("literal") => node!("aaa\nbbb\n  ccc\n\n  ddd\n"),
+                    node!("folded") => node!("aaa{}[] bbb ccc\nddd\n# eee\n"),
+                    node!("literal") => node!("aaa{}[]\nbbb\n  ccc\n\n  ddd\n\n# eee\n"),
                 }),
                 node!({
-                    node!("plain") => node!("aaa \"bbb\" 'ccc', ddd\\n\neee fff"),
-                    node!("single quoted") => node!("aaa \"bbb\" 'ccc', ddd\\n\neee fff"),
-                    node!("double quoted") => node!("aaa \"bbb\" 'ccc', ddd\\n\neee fff"),
+                    node!("plain") => node!("aaa{}[] \"bbb\" 'ccc', ddd\\n\neee fff"),
+                    node!("single quoted") => node!("aaa{}[] \"bbb\" 'ccc', ddd\\n\neee fff\n# ggg"),
+                    node!("double quoted") => node!("aaa{}[] \"bbb\" 'ccc', ddd\\n\neee fff\n# ggg"),
                 }),
+                node!("literal\n\n"),
+                node!("literal"),
             ]),
         })
     );
